@@ -30,33 +30,23 @@
 #include <Lum/Panel.h>
 #include <Lum/String.h>
 #include <Lum/Table.h>
-#include <Lum/Text.h>
 
-class ValuesModelPainter : public Lum::StringCellPainter
-{
-public:
-  std::wstring GetCellData() const
-  {
-    Value value=dynamic_cast<const ValuesModel*>(GetModel())->GetEntry(GetRow());
-
-    return value.value;
-  }
-};
-
-class RangeDialog : public Lum::Dlg::ActionDialog
+class RangeDialog : public Lum::Dialog
 {
 private:
-  Lum::Model::ULongRef  startModel;
-  Lum::Model::ULongRef  endModel;
+  Lum::Model::StringRef startModel;
+  Lum::Model::StringRef endModel;
 
   Lum::Model::ActionRef okAction;
 
   bool                  hasResult;
+  size_t                start;
+  size_t                end;
 
 public:
   RangeDialog()
-   : startModel(new Lum::Model::ULong(1)),
-     endModel(new Lum::Model::ULong(6)),
+   : startModel(new Lum::Model::String(L"1")),
+     endModel(new Lum::Model::String(L"6")),
      okAction(new Lum::Model::Action()),
      hasResult(false)
   {
@@ -66,61 +56,53 @@ public:
     Observe(GetClosedAction());
   }
 
-  Lum::Object* GetContent()
+  void PreInit()
   {
     Lum::String *s,*e;
 
     s=Lum::String::Create(startModel,5,true,false);
     s->SetAlignment(Lum::String::right);
-    s->SetInputTypeHint(Lum::Object::inputTypeUnsignedDecimalNumber);
+    s->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typePosDec));
     e=Lum::String::Create(endModel,5,true,false);
     e->SetAlignment(Lum::String::right);
-    e->SetInputTypeHint(Lum::Object::inputTypeUnsignedDecimalNumber);
+    e->SetInputHelper(new Lum::InputHelperNumber(Lum::InputHelperNumber::typePosDec));
 
-    return Lum::Label::Create(true,false)
+    SetMain(Lum::VPanel::Create(false,false)
+            ->Add(Lum::Label::Create(true,false)
                   ->AddLabel(L"Number range:",
                              Lum::HPanel::Create(true,false)
                              ->Add(s)
                              ->AddSpace()
-                             ->Add(Lum::Text::Create(L"-"))
-                             ->AddSpace()
-                             ->Add(e));
-  }
-
-  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
-  {
-    Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
+                             ->Add(e)))
+            ->AddSpace()
+            ->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false)));
   }
 
   bool HasResult() {
     return hasResult;
   }
 
-  void GetResult(unsigned long &start, unsigned long& end)
+  void GetResult(size_t &start, size_t& end)
   {
     assert(hasResult);
 
-    start=startModel->Get();
-    end=endModel->Get();
+    start=this->start;
+    end=this->end;
   }
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
   {
-    if (model==okAction &&
-        okAction->IsFinished()) {
+    if (model==okAction && okAction->IsFinished()) {
       hasResult=true;
       Exit();
     }
-    else if (model==GetClosedAction() &&
-             GetClosedAction()->IsFinished()) {
+    else if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
       Exit();
     }
     else if (model==startModel || model==endModel) {
-      if (startModel.Valid() &&
-          !startModel->IsNull() &&
-          endModel.Valid() &&
-          !endModel->IsNull() &&
-          endModel->Get()>=startModel->Get()) {
+      if (Lum::Base::WStringToNumber(*startModel,start) &&
+          Lum::Base::WStringToNumber(*endModel,end) &&
+          end>=start) {
         okAction->Enable();
       }
       else {
@@ -128,10 +110,10 @@ public:
       }
     }
 
-    Lum::Dlg::ActionDialog::Resync(model,msg);
+    Lum::Dialog::Resync(model,msg);
   }
 
-  static bool GetRange(Lum::OS::Window* parent, unsigned long& start, unsigned long& end)
+  static bool GetRange(Lum::OS::Window* parent, size_t& start, size_t& end)
   {
     RangeDialog *dlg;
     bool        res;
@@ -200,27 +182,24 @@ void DiceEdit::EvaluateRights()
   }
 }
 
-Lum::Object* DiceEdit::GetContent()
+void DiceEdit::PreInit()
 {
   Lum::Panel            *horiz;
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
-  valuesModel->SetEmptyText(L"(No dice values defined)");
-
   horiz=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(L"Value",Lum::Base::Size::stdCharWidth,20,true);
+  headerModel->AddColumn(L"Value",Lum::Base::Size::stdCharWidth,30,true);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetHeight(Lum::Base::Size::stdCharHeight,8);
-  table->SetShowHeader(false);
+  table->SetShowHeader(true);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetModel(valuesModel);
-  table->SetPainter(new ValuesModelPainter());
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   table->SetDoubleClickAction(editAction);
@@ -237,12 +216,12 @@ Lum::Object* DiceEdit::GetContent()
              ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
-  return horiz;
-}
+  SetMain(Lum::VPanel::Create(true,true)
+          ->Add(horiz)
+          ->AddSpace()
+          ->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false)));
 
-void DiceEdit::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
-{
-  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
+  Dialog::PreInit();
 }
 
 void DiceEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -278,9 +257,9 @@ void DiceEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
     }
   }
   else if (model==addNumbersAction && addNumbersAction->IsFinished()) {
-    bool          result=false;
-    unsigned long start=0;
-    unsigned long end=0;
+    bool   result=false;
+    size_t start=0;
+    size_t end=0;
 
     result=RangeDialog::GetRange(GetWindow(),start,end);
 
@@ -326,7 +305,7 @@ void DiceEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
     EvaluateRights();
   }
 
-  Lum::Dlg::ActionDialog::Resync(model,msg);
+  Dialog::Resync(model,msg);
 }
 
 bool DiceEdit::GetSuccess() const
