@@ -20,20 +20,39 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <Lum/Dlg/ActionDialog.h>
-
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Number.h>
+#include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
+#include <Lum/Dialog.h>
+
 #include "Configuration.h"
 
-typedef Lum::Model::StdRefTable<Value,std::vector<Value> > ValuesModel;
-typedef Lum::Base::Reference<ValuesModel>                  ValuesModelRef;
+class ValuesModel : public Lum::Model::StdRefTable<Value,std::vector<Value> >
+{
+private:
+  class DataProvider : public Lum::Model::StdRefTable<Value,std::vector<Value> >::DataProvider
+  {
+  public:
+    std::wstring GetString(const Iterator& iter, size_t column) const
+    {
+      return iter->value;
+    };
+  };
 
-class DiceEdit : public Lum::Dlg::ActionDialog
+public:
+  ValuesModel(std::vector<Value>& list)
+  : Lum::Model::StdRefTable<Value,std::vector<Value> >(list,new DataProvider())
+  {
+    // no code
+  }
+};
+
+typedef Lum::Base::Reference<ValuesModel> ValuesModelRef;
+
+class DiceEdit : public Lum::Dialog
 {
 private:
   Dice&                              dice;
@@ -56,8 +75,7 @@ private:
 public:
   DiceEdit(Dice& dice);
 
-  Lum::Object* GetContent();
-  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
+  void PreInit();
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 
