@@ -31,27 +31,6 @@
 
 #include "DiceEdit.h"
 
-class DicesModelPainter : public Lum::StringCellPainter
-{
-public:
-  std::wstring GetCellData() const
-  {
-    Dice dice=dynamic_cast<const DicesModel*>(GetModel())->GetEntry(GetRow());
-
-    std::wstring string;
-
-    for (size_t i=0; i<dice.values.size(); i++) {
-      if (i>0) {
-        string.append(L", ");
-      }
-
-      string.append(L"'"+dice.values[i].value+L"'");
-    }
-
-    return string;
-  }
-};
-
 DiceSetEdit::DiceSetEdit(DiceSet& diceSet)
  : diceSet(diceSet),
    name(new Lum::Model::String(diceSet.name)),
@@ -98,14 +77,14 @@ void DiceSetEdit::EvaluateRights()
   }
 }
 
-Lum::Object* DiceSetEdit::GetContent()
+void DiceSetEdit::PreInit()
 {
   Lum::Label            *label;
-  Lum::Panel            *horiz;
+  Lum::Panel            *panel,*horiz;
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
-  dicesModel->SetEmptyText(L"(No dices defined)");
+  panel=Lum::VPanel::Create();
 
   label=Lum::Label::Create(true,true);
   label->AddLabel(L"Name:",Lum::String::Create(name,true,false));
@@ -113,16 +92,15 @@ Lum::Object* DiceSetEdit::GetContent()
   horiz=Lum::HPanel::Create(true,true);
 
   headerModel=new Lum::Model::HeaderImpl();
-  headerModel->AddColumn(L"Values",Lum::Base::Size::stdCharWidth,20,true);
+  headerModel->AddColumn(L"Values",Lum::Base::Size::stdCharWidth,25,true);
 
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetHeight(Lum::Base::Size::stdCharHeight,6);
-  table->SetShowHeader(false);
+  table->SetShowHeader(true);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetModel(dicesModel);
-  table->SetPainter(new DicesModelPainter());
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   table->SetDoubleClickAction(editAction);
@@ -134,18 +112,19 @@ Lum::Object* DiceSetEdit::GetContent()
              ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Edit"),editAction,true,false))
              ->AddSpace()
-             ->Add(Lum::Button::Create(_(L"BTN_CLONE",L"_Duplicate"),cloneAction,true,false))
+             ->Add(Lum::Button::Create(_(L"BTN_CLONE",L"_Dupplicate"),cloneAction,true,false))
              ->AddSpace()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
   label->AddLabel(L"Dices:",horiz);
 
-  return label;
-}
+  panel->Add(label);
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
-void DiceSetEdit::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
-{
-  Lum::Dlg::ActionDialog::CreateActionInfosOkCancel(actions,okAction,GetClosedAction());
+  SetMain(panel);
+
+  Dialog::PreInit();
 }
 
 void DiceSetEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -227,7 +206,7 @@ void DiceSetEdit::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
     configurationChanged=true;
   }
 
-  Lum::Dlg::ActionDialog::Resync(model,msg);
+  Dialog::Resync(model,msg);
 }
 
 bool DiceSetEdit::GetResult() const
