@@ -20,20 +20,49 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <Lum/Dlg/ActionDialog.h>
-
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Number.h>
+#include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
+#include <Lum/Dialog.h>
+
 #include "Configuration.h"
 
-typedef Lum::Model::StdRefTable<Dice>    DicesModel;
+class DicesModel : public Lum::Model::StdRefTable<Dice>
+{
+private:
+  class DataProvider : public Lum::Model::StdRefTable<Dice>::DataProvider
+  {
+  public:
+    std::wstring GetString(const Iterator& iter, size_t column) const
+    {
+      std::wstring string;
+
+      for (size_t i=0; i<iter->values.size(); i++) {
+        if (i>0) {
+          string.append(L", ");
+        }
+
+        string.append(L"'"+iter->values[i].value+L"'");
+      }
+
+      return string;
+    };
+  };
+
+public:
+  DicesModel(std::list<Dice>& list)
+  : Lum::Model::StdRefTable<Dice>(list,new DataProvider())
+  {
+    // no code
+  }
+};
+
 typedef Lum::Base::Reference<DicesModel> DicesModelRef;
 
-class DiceSetEdit : public Lum::Dlg::ActionDialog
+class DiceSetEdit : public Lum::Dialog
 {
 private:
   DiceSet&                           diceSet;
@@ -58,8 +87,7 @@ private:
 public:
   DiceSetEdit(DiceSet& diceSet);
 
-  Lum::Object* GetContent();
-  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
+  void PreInit();
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 
