@@ -59,13 +59,13 @@ void DiceSetList::EvaluateRights()
   }
 }
 
-Lum::Object* DiceSetList::GetContent()
+void DiceSetList::PreInit()
 {
   Lum::Panel            *panel,*horiz;
   Lum::Table            *table;
   Lum::Model::HeaderRef headerModel;
 
-  panel=Lum::VPanel::Create(true,true);
+  panel=Lum::VPanel::Create();
 
   horiz=Lum::HPanel::Create(true,true);
 
@@ -74,13 +74,11 @@ Lum::Object* DiceSetList::GetContent()
 
   table=new Lum::Table();
   table->SetFlex(true,true);
-  table->SetWidth(Lum::Base::Size::stdCharWidth,20);
-  table->SetHeight(Lum::Base::Size::stdCharHeight,10);
-  table->SetShowHeader(false);
+  table->SetHeight(Lum::Base::Size::stdCharHeight,8);
+  table->SetShowHeader(true);
   table->GetTableView()->SetAutoHSize(true);
   table->GetTableView()->SetAutoFitColumns(true);
   table->SetModel(setsModel);
-  table->SetPainter(new DiceSetModelPainter());
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   table->SetDoubleClickAction(editAction);
@@ -95,13 +93,12 @@ Lum::Object* DiceSetList::GetContent()
              ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
   panel->Add(horiz);
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::CreateOk(GetClosedAction(),true,false));
 
-  return panel;
-}
+  SetMain(panel);
 
-void DiceSetList::GetActions(std::vector<Lum::Dlg::ActionInfo>& actions)
-{
-  Lum::Dlg::ActionDialog::CreateActionInfosClose(actions,GetClosedAction());
+  Dialog::PreInit();
 }
 
 void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
@@ -154,18 +151,14 @@ void DiceSetList::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& ms
 
     delete dialog;
   }
-  else if (model==removeAction &&
-           removeAction->IsFinished() &&
-           removeAction->IsEnabled()) {
+  else if (model==removeAction && removeAction->IsFinished() && removeAction->IsEnabled()) {
     assert(selection->HasSelection());
 
     setsModel->Delete(selection->GetLine());
-    currentSet->Off();
-
     EvaluateRights();
     configurationChanged=true;
   }
 
-  Lum::Dlg::ActionDialog::Resync(model,msg);
+  Dialog::Resync(model,msg);
 }
 
