@@ -20,15 +20,15 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <Lum/Dlg/ActionDialog.h>
-
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Number.h>
+#include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
 #include <Lum/Model/String.h>
 #include <Lum/Model/Table.h>
 
-class DiceSetList : public Lum::Dlg::ActionDialog
+#include <Lum/Dialog.h>
+
+class DiceSetList : public Lum::Dialog
 {
 private:
   Lum::Model::SingleLineSelectionRef selection;
@@ -43,8 +43,7 @@ private:
 public:
   DiceSetList();
 
-  Lum::Object* GetContent();
-  void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
+  void PreInit();
 
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
 };
